Documentation
¶
Overview ¶
Package hplot is a package to plot histograms, n-tuples and functions
Example (Diffplot) ¶
package main
import (
"image/color"
"log"
"math"
"os"
"go-hep.org/x/hep/hbook"
"go-hep.org/x/hep/hplot"
"golang.org/x/exp/rand"
"gonum.org/v1/gonum/stat/distuv"
"gonum.org/v1/plot/vg"
"gonum.org/v1/plot/vg/draw"
"gonum.org/v1/plot/vg/vgimg"
)
func main() {
const npoints = 10000
// Create a normal distribution.
dist := distuv.Normal{
Mu: 0,
Sigma: 1,
Src: rand.New(rand.NewSource(0)),
}
hist1 := hbook.NewH1D(20, -4, +4)
hist2 := hbook.NewH1D(20, -4, +4)
for i := 0; i < npoints; i++ {
v1 := dist.Rand()
v2 := dist.Rand() + 0.5
hist1.Fill(v1, 1)
hist2.Fill(v2, 1)
}
// Make a plot and set its title.
p1 := hplot.New()
p1.Title.Text = "Histos"
p1.Y.Label.Text = "Y"
// Create a histogram of our values drawn
// from the standard normal.
h1 := hplot.NewH1D(hist1)
h1.LineStyle.Color = color.RGBA{R: 255, A: 255}
h1.FillColor = nil
p1.Add(h1)
h2 := hplot.NewH1D(hist2)
h2.LineStyle.Color = color.RGBA{B: 255, A: 255}
h2.FillColor = nil
p1.Add(h2)
// hide X-axis labels
p1.X.Tick.Marker = hplot.NoTicks{}
p1.Add(hplot.NewGrid())
hist3 := hbook.NewH1D(20, -4, +4)
for i := 0; i < hist3.Len(); i++ {
v1 := hist1.Value(i)
v2 := hist2.Value(i)
x1, _ := hist1.XY(i)
hist3.Fill(x1, v1-v2)
}
hdiff := hplot.NewH1D(hist3)
p2 := hplot.New()
p2.X.Label.Text = "X"
p2.Y.Label.Text = "Delta-Y"
p2.Add(hdiff)
p2.Add(hplot.NewGrid())
const (
width = 15 * vg.Centimeter
height = width / math.Phi
)
c := vgimg.PngCanvas{Canvas: vgimg.New(width, height)}
dc := draw.New(c)
top := draw.Canvas{
Canvas: dc,
Rectangle: vg.Rectangle{
Min: vg.Point{X: 0, Y: 0.3 * height},
Max: vg.Point{X: width, Y: height},
},
}
p1.Draw(top)
bottom := draw.Canvas{
Canvas: dc,
Rectangle: vg.Rectangle{
Min: vg.Point{X: 0, Y: 0},
Max: vg.Point{X: width, Y: 0.3 * height},
},
}
p2.Draw(bottom)
f, err := os.Create("testdata/diff_plot.png")
if err != nil {
log.Fatalf("error: %v\n", err)
}
defer f.Close()
_, err = c.WriteTo(f)
if err != nil {
log.Fatal(err)
}
err = f.Close()
if err != nil {
log.Fatal(err)
}
}
Output:
Example (Latexplot) ¶
package main
import (
"image/color"
"log"
"math"
"os"
"go-hep.org/x/hep/hbook"
"go-hep.org/x/hep/hplot"
"golang.org/x/exp/rand"
"gonum.org/v1/gonum/stat/distuv"
"gonum.org/v1/plot/vg"
"gonum.org/v1/plot/vg/draw"
"gonum.org/v1/plot/vg/vgtex"
)
func main() {
const npoints = 10000
// Create a normal distribution.
dist := distuv.Normal{
Mu: 0,
Sigma: 1,
Src: rand.New(rand.NewSource(0)),
}
hist := hbook.NewH1D(20, -4, +4)
for i := 0; i < npoints; i++ {
v := dist.Rand()
hist.Fill(v, 1)
}
// Make a plot and set its title.
p := hplot.New()
p.Title.Text = `Gaussian distribution: $f(x) = \frac{e^{-(x - \mu)^{2}/(2\sigma^{2}) }} {\sigma\sqrt{2\pi}}$`
p.Y.Label.Text = `$f(x)$`
p.X.Label.Text = `$x$`
// Create a histogram of our values drawn
// from the standard normal.
h := hplot.NewH1D(hist)
h.LineStyle.Color = color.RGBA{R: 255, A: 255}
h.FillColor = nil
h.Infos.Style = hplot.HInfoSummary
p.Add(h)
p.Add(hplot.NewGrid())
const (
width = 15 * vg.Centimeter
height = width / math.Phi
)
c := vgtex.NewDocument(width, height)
p.Draw(draw.New(c))
f, err := os.Create("testdata/latex_plot.tex")
if err != nil {
log.Fatalf("error: %v\n", err)
}
defer f.Close()
_, err = c.WriteTo(f)
if err != nil {
log.Fatal(err)
}
err = f.Close()
if err != nil {
log.Fatal(err)
}
}
Output:
Example (Subplot) ¶
An example of a plot + sub-plot
package main
import (
"image/color"
"log"
"math"
"os"
"go-hep.org/x/hep/hbook"
"go-hep.org/x/hep/hplot"
"golang.org/x/exp/rand"
"gonum.org/v1/gonum/stat/distuv"
"gonum.org/v1/plot/vg"
"gonum.org/v1/plot/vg/draw"
"gonum.org/v1/plot/vg/vgimg"
)
func main() {
const npoints = 10000
// Create a normal distribution.
dist := distuv.Normal{
Mu: 0,
Sigma: 1,
Src: rand.New(rand.NewSource(0)),
}
// Draw some random values from the standard
// normal distribution.
hist := hbook.NewH1D(20, -4, +4)
for i := 0; i < npoints; i++ {
v := dist.Rand()
hist.Fill(v, 1)
}
// normalize histo
area := 0.0
for _, bin := range hist.Binning().Bins() {
area += bin.SumW() * bin.XWidth()
}
hist.Scale(1 / area)
// Make a plot and set its title.
p1 := hplot.New()
p1.Title.Text = "Histogram"
p1.X.Label.Text = "X"
p1.Y.Label.Text = "Y"
// Create a histogram of our values drawn
// from the standard normal.
h := hplot.NewH1D(hist)
p1.Add(h)
// The normal distribution function
norm := hplot.NewFunction(dist.Prob)
norm.Color = color.RGBA{R: 255, A: 255}
norm.Width = vg.Points(2)
p1.Add(norm)
// draw a grid
p1.Add(hplot.NewGrid())
// make a second plot which will be diplayed in the upper-right
// of the previous one
p2 := hplot.New()
p2.Title.Text = "Sub plot"
p2.Add(h)
p2.Add(hplot.NewGrid())
const (
width = 15 * vg.Centimeter
height = width / math.Phi
)
c := vgimg.PngCanvas{Canvas: vgimg.New(width, height)}
dc := draw.New(c)
p1.Draw(dc)
sub := draw.Canvas{
Canvas: dc,
Rectangle: vg.Rectangle{
Min: vg.Point{X: 0.70 * width, Y: 0.50 * height},
Max: vg.Point{X: 1.00 * width, Y: 1.00 * height},
},
}
p2.Draw(sub)
f, err := os.Create("testdata/sub_plot.png")
if err != nil {
log.Fatalf("error: %v\n", err)
}
defer f.Close()
_, err = c.WriteTo(f)
if err != nil {
log.Fatal(err)
}
err = f.Close()
if err != nil {
log.Fatal(err)
}
}
Output:
Index ¶
- func NewFunction(f func(float64) float64) *plotter.Function
- func NewGrid() *plotter.Grid
- func NewLine(xys plotter.XYer) (*plotter.Line, error)
- func NewScatter(xys plotter.XYer) (*plotter.Scatter, error)
- func Show(p *Plot, w, h vg.Length, format string) ([]byte, error)
- func ZipXY(x, y []float64) plotter.XYer
- type FreqTicks
- type H1D
- type H2D
- type HInfoStyle
- type HInfos
- type NoTicks
- type Options
- type Plot
- type S2D
- type Style
- type TiledPlot
- func (tp *TiledPlot) Draw(c draw.Canvas)
- func (tp *TiledPlot) Plot(i, j int) *Plot
- func (tp *TiledPlot) Save(w, h vg.Length, file string) (err error)
- func (tp *TiledPlot) Show(w, h vg.Length, scr screen.Screen) (*vgshiny.Canvas, error)
- func (tp *TiledPlot) WriterTo(w, h vg.Length, format string) (io.WriterTo, error)
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFunction ¶
NewFunction returns a Function that plots F using the default line style with 50 samples. NewFunction returns a Function that plots F using the default line style with 50 samples.
func NewGrid ¶
NewGrid returns a new grid with both vertical and horizontal lines using the default grid line style.
func NewScatter ¶
NewScatter returns a Scatter that uses the default glyph style.
Types ¶
type FreqTicks ¶
FreqTicks implements a simple plot.Ticker scheme. FreqTicks will generate N ticks where 1 every Freq tick will be labeled.
type H1D ¶
type H1D struct {
// Hist is the histogramming data
Hist *hbook.H1D
// FillColor is the color used to fill each
// bar of the histogram. If the color is nil
// then the bars are not filled.
FillColor color.Color
// LineStyle is the style of the outline of each
// bar of the histogram.
draw.LineStyle
// InfoStyle is the style of infos displayed for
// the histogram (entries, mean, rms)
Infos HInfos
}
H1D implements the plotter.Plotter interface, drawing a histogram of the data.
func NewH1D ¶
NewH1D returns a new histogram, as in NewH1DFromXYer, except that it accepts a hbook.H1D instead of a plotter.XYer
func NewH1FromValuer ¶
NewH1FromValuer returns a new histogram, as in NewH1FromXYer, except that it accepts a plotter.Valuer instead of an XYer.
func NewH1FromXYer ¶
NewH1FromXYer returns a new histogram that represents the distribution of values using the given number of bins.
Each y value is assumed to be the frequency count for the corresponding x.
It panics if the number of bins is non-positive.
func (*H1D) GlyphBoxes ¶
GlyphBoxes returns a slice of GlyphBoxes, one for each of the bins, implementing the plot.GlyphBoxer interface.
type H2D ¶
type H2D struct {
// H is the histogramming data
H *hbook.H2D
// Palette is the color palette used to render
// the heat map. Palette must not be nil or
// return a zero length []color.Color.
Palette palette.Palette
// InfoStyle is the style of infos displayed for
// the histogram (entries, mean, rms)
Infos HInfos
// contains filtered or unexported fields
}
H2D implements the plotter.Plotter interface, drawing a 2-dim histogram of the data.
func (*H2D) GlyphBoxes ¶
GlyphBoxes returns a slice of GlyphBoxes, one for each of the bins, implementing the plot.GlyphBoxer interface.
type HInfoStyle ¶
type HInfoStyle uint32
const ( HInfoNone HInfoStyle = 0 HInfoEntries HInfoStyle = 1 << iota HInfoMean HInfoRMS HInfoStdDev HInfoSummary HInfoStyle = HInfoEntries | HInfoMean | HInfoStdDev )
type HInfos ¶
type HInfos struct {
Style HInfoStyle
}
type Plot ¶
Plot is the basic type representing a plot.
func (*Plot) Add ¶
Add adds a Plotters to the plot.
If the plotters implements DataRanger then the minimum and maximum values of the X and Y axes are changed if necessary to fit the range of the data.
When drawing the plot, Plotters are drawn in the order in which they were added to the plot.
func (*Plot) Save ¶
Save saves the plot to an image file. The file format is determined by the extension.
Supported extensions are:
.eps, .jpg, .jpeg, .pdf, .png, .svg, .tif and .tiff.
If w or h are <= 0, the value is chosen such that it follows the Golden Ratio. If w and h are <= 0, the values are chosen such that they follow the Golden Ratio (the width is defaulted to vgimg.DefaultWidth).
type S2D ¶
type S2D struct {
Data plotter.XYer
// GlyphStyle is the style of the glyphs drawn
// at each point.
draw.GlyphStyle
// contains filtered or unexported fields
}
S2D plots a set of 2-dim points with error bars.
func (*S2D) DataRange ¶
DataRange returns the minimum and maximum x and y values, implementing the plot.DataRanger interface.
func (*S2D) GlyphBoxes ¶
GlyphBoxes returns a slice of plot.GlyphBoxes, implementing the plot.GlyphBoxer interface.
type Style ¶
type Style struct {
Fonts struct {
Name string // font name of this style
Title vg.Font // font used for the plot title
Label vg.Font // font used for the plot labels
Legend vg.Font // font used for the plot legend
Tick vg.Font // font used for the plot's axes' ticks
}
}
Style stores a given plot style.
var ( // DefaultStyle is the default style used for hplot plots. DefaultStyle Style )
type TiledPlot ¶
TiledPlot is a regularly spaced set of plots, aranged as tiles.
func NewTiledPlot ¶
NewTiledPlot creates a new set of plots aranged as tiles. By default, NewTiledPlot will put a 1 vg.Length space between each plot.
func (*TiledPlot) Draw ¶
Draw draws the tiled plot to a draw.Canvas.
Each non-nil plot.Plot in the aranged set of tiled plots is drawn inside its dedicated sub-canvas, using hplot.Plot.Draw.
func (*TiledPlot) Plot ¶
Plot returns the plot at the i-th column and j-th row in the set of tiles. (0,0) is at the top-left of the set of tiles.
func (*TiledPlot) Save ¶
Save saves the plots to an image file. The file format is determined by the extension.
Supported extensions are the same ones than hplot.Plot.Save.
If w or h are <= 0, the value is chosen such that it follows the Golden Ratio. If w and h are <= 0, the values are chosen such that they follow the Golden Ratio (the width is defaulted to vgimg.DefaultWidth).
func (*TiledPlot) Show ¶
Show displays the plots to the screen, with the given dimensions.
If w or h are <= 0, the value is chosen such that it follows the Golden Ratio. If w and h are <= 0, the values are chosen such that they follow the Golden Ratio (the width is defaulted to vgimg.DefaultWidth).
func (*TiledPlot) WriterTo ¶
WriterTo returns an io.WriterTo that will write the plots as the specified image format.
Supported formats are the same ones than hplot.Plot.WriterTo ¶
If w or h are <= 0, the value is chosen such that it follows the Golden Ratio. If w and h are <= 0, the values are chosen such that they follow the Golden Ratio (the width is defaulted to vgimg.DefaultWidth).
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
hplot
command
hplot is a simple gnuplot-like command to create plots
|
hplot is a simple gnuplot-like command to create plots |
|
iplot
command
|
|
|
internal
|
|
|
cmpimg
Package cmpimg compares the raw representation of images taking into account idiosyncracies related to their underlying format (SVG, PDF, PNG, ...).
|
Package cmpimg compares the raw representation of images taking into account idiosyncracies related to their underlying format (SVG, PDF, PNG, ...). |
|
Package vgshiny provides a vg.Canvas implementation backed by a shiny/screen.Window
|
Package vgshiny provides a vg.Canvas implementation backed by a shiny/screen.Window |